@@ -1,9 +1,12 @@
 test_that("network plot, basic functionality", {
         model <- adproclus(stackloss,
                            nclusters = 4,
-                           nrandomstart = 1, nsemirandomstart = 1
+                           nrandomstart = 1, nsemirandomstart = 1,
+                           seed = 1
         )
-        modelLD <- adproclus_low_dim(stackloss, 3, 2)
+
+
+        modelLD <- adproclus_low_dim(stackloss, 3, 2, seed = 1)
         expect_no_condition(plot_cluster_network(model))
         expect_no_error(plot_cluster_network(model,
                                              title = "Test network",
@@ -21,14 +24,15 @@ test_that("network plot, basic functionality", {
 test_that("profile plot, basic functionality", {
         model <- adproclus(stackloss,
                            nclusters = 4,
-                           nrandomstart = 1, nsemirandomstart = 1
+                           nrandomstart = 1, nsemirandomstart = 1,
+                           seed = 1
         )
-        modelLD <- adproclus_low_dim(stackloss, 3, 2)
+        modelLD <- adproclus_low_dim(stackloss, 3, 2, seed = 1)
         expect_no_condition(plot_profiles(model))
         expect_no_condition(plot_profiles(modelLD))
 })
 
 test_that("VarsByComp plot, basic functionality", {
-        modelLD <- adproclus_low_dim(stackloss, 3, 2)
+        modelLD <- adproclus_low_dim(stackloss, 3, 2, seed = 1)
         expect_no_condition(plot_vars_by_comp(modelLD))
 })
